@@ -1,5 +1,5 @@
 ###########################################################################/**
-# @RdocDefault jpeg2
+# @RdocFunction jpeg2
 #
 # @title "A JPEG device for Bitmap Files via GhostScript"
 #
@@ -25,13 +25,16 @@
 #
 # @keyword device
 #*/########################################################################### 
-setMethodS3("jpeg2", "default", function(filename, width=480, height=480, res=144, type="jpeg", ...) {
+jpeg2 <- function(filename, width=480, height=480, res=144, type="jpeg", ...) {
   bitmap(file=filename, type=type, width=width/res, height=height/res, res=res, ...);
-})
+}
 
 
 ############################################################################
 # HISTORY:
+# 2011-10-05
+# o Turned jpeg2() into a plain function without a generic.  This is
+#   consistent with how eps() is defined. 
 # 2005-09-18
 # o Created.
 ############################################################################
